<?php

	function efor_after_setup_theme()
	{
		load_theme_textdomain('efor', get_template_directory() . '/languages');
		register_nav_menus(array('efor_theme_menu_location' => esc_html__('Theme Navigation Menu', 'efor')));
		
		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support('html5', array('comment-list', 'comment-form', 'search-form', 'gallery', 'caption'));
		add_theme_support('post-formats', array('image', 'gallery', 'audio', 'video', 'quote', 'link', 'chat', 'status', 'aside'));
		add_theme_support('post-thumbnails');
		add_theme_support('customize-selective-refresh-widgets');
		
		add_theme_support('woocommerce');
		add_theme_support('wc-product-gallery-lightbox');
		add_theme_support('wc-product-gallery-zoom');
		add_theme_support('wc-product-gallery-slider');
		
		add_theme_support(
			'custom-logo',
			array(
				'width'       => 1920,
				'height'      => 160,
				'flex-width'  => true,
				'flex-height' => true
			)
		);
	}
	
	add_action('after_setup_theme', 'efor_after_setup_theme');


/* ============================================================================================================================================= */


	include_once(get_template_directory() . '/admin/enqueue-styles-scripts.php');
	include_once(get_template_directory() . '/admin/enqueue-inline-style.php');
	include_once(get_template_directory() . '/admin/enqueue-inline-script.php');
	include_once(get_template_directory() . '/admin/image-sizes.php');


/* ============================================================================================================================================= */


	/*
		To override this walker in a child theme without modifying the comments template
		simply create your own efor_theme_comments(), and that function will be used instead.
		
		Used as a callback by wp_list_comments() for displaying the comments.
	*/
	
	function efor_theme_comments($comment, $args, $depth)
	{
		$GLOBALS['comment'] = $comment;
		
		switch ($comment->comment_type)
		{
			case 'pingback' :
			
			case 'trackback' :
			
				?>
					<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
						<p>
							<?php
								esc_html_e('Pingback:', 'efor');
							?>
							<?php
								comment_author_link();
							?>
							<?php
								edit_comment_link(esc_html__('(Edit)', 'efor'), '<span class="edit-link">', '</span>');
							?>
						</p>
				<?php
			
			break;
			
			default :
			
				global $post;
				
				?>
					<li id="li-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
						<article id="comment-<?php comment_ID(); ?>" class="comment">
							<header class="comment-meta comment-author vcard">
								<?php
									echo get_avatar($comment, 150);
								?>
								<cite class="fn">
									<?php
										echo get_comment_author_link();
									?>
								</cite>
								<span class="comment-date">
									<?php
										echo get_comment_date();
									?>
									<?php
										esc_html_e('at', 'efor');
									?>
									<?php
										echo get_comment_time();
									?>
									<?php
										edit_comment_link(esc_html__('Edit', 'efor'), '<span class="comment-edit-link">', '</span>');
									?>
								</span>
							</header>
							
							<section class="comment-content comment">
								<?php
									if ('0' == $comment->comment_approved)
									{
										?>
											<p class="comment-awaiting-moderation">
												<?php
													esc_html_e('Your comment is awaiting moderation.', 'efor');
												?>
											</p>
										<?php
									}
								?>
								<?php
									comment_text();
								?>
							</section>
							
							<div class="reply">
								<?php
									comment_reply_link(array_merge($args,
																   array('reply_text' => esc_html__('Reply', 'efor'),
																		 'after'      => ' ' . '<span>' . esc_html__('&#8595;', 'efor') . '</span>',
																		 'depth'      => $depth,
																		 'max_depth'  => $args['max_depth'])));
								?>
							</div>
						</article>
				<?php
			
			break;
		}
	}


/* ============================================================================================================================================= */


	function efor_post_tags()
	{
		$tags = get_theme_mod('efor_setting_tags', 'Yes');
		
		if ($tags != 'No')
		{
			if (get_the_tags() != "")
			{
				?>
					<div class="post-tags tagcloud">
						<?php
							the_tags("", ' ', "");
						?>
					</div>
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	function efor_about_author_html()
	{
		?>
			<aside class="about-author">
				<h3 class="widget-title">
					<span>
						<?php
							esc_html_e('Written By', 'efor');
						?>
					</span>
				</h3> <!-- .widget-title -->
				<div class="author-bio">
					<div class="author-img">
						<a href="<?php echo get_author_posts_url(get_the_author_meta('ID')); ?>">
							<?php
								echo get_avatar(get_the_author_meta('user_email'), 300, "", get_the_author_meta('display_name'));
							?>
						</a>
					</div> <!-- .author-img -->
					<div class="author-info">
						<h4 class="author-name">
							<?php
								the_author();
							?>
						</h4> <!-- .author-name -->
						<p>
							<?php	
								echo get_the_author_meta('description');
							?>
						</p>
						<?php
							dynamic_sidebar('efor_sidebar_8');
						?>
					</div> <!-- .author-info -->
				</div> <!-- .author-bio -->
			</aside> <!-- .about-author -->
		<?php
	}
	
	
	function efor_about_author()
	{
		if (is_singular('post'))
		{
			$author_info_box   = get_theme_mod('efor_setting_author_info_box', 'yes_with_bio_info');
			$biographical_info = get_the_author_meta('description');
			
			if ($author_info_box == 'yes')
			{
				efor_about_author_html();
			}
			elseif (($author_info_box == 'yes_with_bio_info') && (! empty($biographical_info)))
			{
				efor_about_author_html();
			}
		}
	}


/* ============================================================================================================================================= */


	function efor_blog_navigation()
	{
		$numbered_pagination = get_theme_mod('efor_setting_numbered_pagination', 'No');
		
		if ($numbered_pagination == 'Yes')
		{
			the_posts_pagination(array('screen_reader_text' => esc_html__('Posts navigation', 'efor'),
									   'prev_text'          => esc_html__('Prev', 'efor'),
									   'next_text'          => esc_html__('Next', 'efor'),
									   'end_size' 			=> 1,
									   'mid_size' 			=> 1,
									   'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__('Page', 'efor') . ' </span>'));
		}
		else
		{
			$next_posts_link     = get_next_posts_link();
			$previous_posts_link = get_previous_posts_link();
			
			if (($next_posts_link != "") || ($previous_posts_link != ""))
			{
				?>
					<nav class="navigation" role="navigation">
						<div class="nav-previous">
							<?php
								next_posts_link('&#8592; ' . esc_html__('Older Posts', 'efor'));
							?>
						</div> <!-- .nav-previous -->
						<div class="nav-next">
							<?php
								previous_posts_link(esc_html__('Newer Posts', 'efor') . ' &#8594;');
							?>
						</div> <!-- .nav-next -->
					</nav> <!-- .navigation -->
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	if (! function_exists('efor_single_navigation_html'))
	{
		function efor_single_navigation_html()
		{
			if (wp_attachment_is_image())
			{
				?>
					<nav class="nav-single">
						<div class="nav-previous">
							<div class="nav-desc">
								<?php
									previous_image_link(false, '<span class="meta-nav">&#8592;</span>' . esc_html__('Previous Image', 'efor'));
								?>
							</div>
						</div>
						<div class="nav-next">
							<div class="nav-desc">
								<?php
									next_image_link(false, esc_html__('Next Image', 'efor') . '<span class="meta-nav">&#8594;</span>');
								?>
							</div>
						</div>
					</nav>
				<?php
			}
			else
			{
				$previous_post_link = get_previous_post_link();
				$next_post_link     = get_next_post_link();
				
				if (($previous_post_link != "") || ($next_post_link != ""))
				{
					$previous_post = (is_attachment()) ? get_post(get_post()->post_parent) : get_adjacent_post(false, '', true);
					$next_post     = get_adjacent_post(false, '', false);
					
					?>
						<nav class="nav-single">
							<div class="nav-previous">
								<?php
									if ($previous_post &&  has_post_thumbnail($previous_post->ID))
									{
										$feat_img  = wp_get_attachment_image_src(get_post_thumbnail_id($previous_post->ID), 'efor_image_size_5');
										$feat_img_alt = get_post_meta(get_post_thumbnail_id($previous_post->ID), '_wp_attachment_image_alt', true);
										
										?>
											<a class="nav-image-link" href="<?php echo get_permalink($previous_post->ID); ?>">
												<img alt="<?php echo esc_attr($feat_img_alt); ?>" src="<?php echo esc_url($feat_img[0]); ?>">
											</a>
										<?php
									}
								?>
								
								<?php
									previous_post_link('<div class="nav-desc"><h4>' . esc_html__('Previous Post', 'efor') . '</h4>%link</div>',
													   '<span class="meta-nav">&#8592;</span> %title');
								?>
								
								<?php
									if ($previous_post)
									{
										?>
											<a class="nav-overlay-link" href="<?php echo get_permalink($previous_post->ID); ?>" rel="prev">
												<?php
													echo esc_html($previous_post->post_title);
												?>
											</a>
										<?php
									}
								?>
							</div>
							
							<div class="nav-next">
								<?php
									if ($next_post && has_post_thumbnail($next_post->ID))
									{
										$feat_img = wp_get_attachment_image_src(get_post_thumbnail_id($next_post->ID), 'efor_image_size_5');
										$feat_img_alt = get_post_meta(get_post_thumbnail_id($next_post->ID), '_wp_attachment_image_alt', true);
										
										?>
											<a class="nav-image-link" href="<?php echo get_permalink($next_post->ID); ?>">
												<img alt="<?php echo esc_attr($feat_img_alt); ?>" src="<?php echo esc_url($feat_img[0]); ?>">
											</a>
										<?php
									}
								?>
								
								<?php
									next_post_link('<div class="nav-desc"><h4>' . esc_html__('Next Post', 'efor') . '</h4>%link</div>',
												   '%title <span class="meta-nav">&#8594;</span>');
								?>
								
								<?php
									if ($next_post)
									{
										?>
											<a class="nav-overlay-link" href="<?php echo get_permalink($next_post->ID); ?>" rel="next">
												<?php
													echo esc_html($next_post->post_title);
												?>
											</a>
										<?php
									}
								?>
							</div>
						</nav>
					<?php
				}
			}
		}
	}
	
	
	if (! function_exists('efor_single_navigation'))
	{
		function efor_single_navigation()
		{
			$post_navigation = get_theme_mod('efor_setting_post_navigation', 'Yes');
			
			if ($post_navigation != 'No')
			{
				efor_single_navigation_html();
			}
		}
	}


/* ============================================================================================================================================= */


	function efor_html_class()
	{
		$html_class = "";
		
		if ((is_home() && is_active_sidebar('efor_sidebar_13')) || (is_page_template('page_template-latest_posts.php') && is_active_sidebar('efor_sidebar_14')))
		{
			$html_class .= 'is-featured-area-on' . ' ';
		}
		else
		{
			$html_class .= 'no-featured-area' . ' ';
		}
		
		$html_class .= get_theme_mod('efor_setting_body_layout', 'is-body-full-width') . ' ';
		$html_class .= get_theme_mod('efor_setting_post_title_style', 'is-single-post-title-default') . ' ';
		$html_class .= get_theme_mod('efor_setting_post_page_title_text_align', 'is-post-title-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_post_media_width', 'is-post-media-fixed') . ' ';
		$html_class .= get_theme_mod('efor_setting_blog_text_align', 'is-blog-text-align-left') . ' ';
		$html_class .= get_theme_mod('efor_setting_meta_prefix_style', 'is-meta-with-icons') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_header_layout', 'is-menu-bottom is-menu-bar') . ' '; // Also used in header.php
		
		if (isset($_GET['header_layout']))
		{
			if ($_GET['header_layout'] == 'small')
			{
				$html_class .= 'is-header-small' . ' ';
			}
			elseif ($_GET['header_layout'] == 'one_row')
			{
				$html_class .= 'is-header-row' . ' ';
			}
			elseif ($_GET['header_layout'] == 'menu_bottom')
			{
				$html_class .= 'is-menu-bottom is-menu-bar' . ' ';
			}
			else
			{
				$html_class .= 'is-menu-top is-menu-bar' . ' ';
			}
		}
		
		$html_class .= get_theme_mod('efor_setting_header_text_color', 'is-header-light') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_width', 'is-header-full-width') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_parallax_effect', 'is-header-parallax-no') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_menu_behaviour', 'is-menu-sticky') . ' ';
		$html_class .= get_theme_mod('efor_setting_menu_width', 'is-menu-fixed-width') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_menu_align', 'is-menu-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_menu_style', 'is-menu-light') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_sub_menu_style', 'is-submenu-dark') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_sub_menu_align', 'is-submenu-align-left') . ' ';
		$html_class .= get_theme_mod('efor_setting_header_menu_text_transform', 'is-menu-uppercase') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_feat_area_width', 'is-featured-area-fixed') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_main_slider_nav_position', 'is-slider-buttons-center-margin') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_nav_shape', 'is-slider-buttons-rounded') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_nav_style', 'is-slider-buttons-dark') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_title_style', 'is-slider-title-default') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_parallax_effect', 'is-slider-parallax') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_title_text_transform', 'is-slider-title-none-uppercase') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_more_link_visibility', 'is-slider-more-link-show') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_more_link_style', 'is-slider-more-link-button-style') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_text_align', 'is-slider-text-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_vertical_align', 'is-slider-v-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_main_slider_horizontal_align', 'is-slider-h-align-center') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_link_box_title_style', 'is-link-box-title-default') . ' ';
		$html_class .= get_theme_mod('efor_setting_link_box_text_transform', 'is-link-box-title-transform-none') . ' ';
		$html_class .= get_theme_mod('efor_setting_link_box_text_align', 'is-link-box-text-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_link_box_vertical_align', 'is-link-box-v-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_link_box_parallax_effect', 'is-link-box-parallax') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_intro_text_align', 'is-intro-align-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_intro_text_color', 'is-intro-text-dark') . ' ';
		$html_class .= get_theme_mod('efor_setting_intro_parallax_bg_img', 'is-intro-parallax-no') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_more_link_style', 'is-more-link-button-style') . ' ';
		$html_class .= get_theme_mod('efor_setting_author_info_box_style', 'is-about-author-minimal') . ' ';
		$html_class .= get_theme_mod('efor_setting_related_posts_parallax_effect', 'is-related-posts-parallax') . ' ';
		$html_class .= get_theme_mod('efor_setting_related_posts_width', 'is-related-posts-overflow') . ' ';
		$html_class .= get_theme_mod('efor_setting_share_links_style', 'is-share-links-boxed') . ' ';
		$html_class .= get_theme_mod('efor_setting_tag_cloud_style', 'is-tagcloud-minimal') . ' ';
		$html_class .= get_theme_mod('efor_setting_post_nav_image', 'is-nav-single-rounded') . ' ';
		$html_class .= get_theme_mod('efor_setting_post_nav_animated', 'is-nav-single-no-animated') . ' ';
		$html_class .= get_theme_mod('efor_setting_comments_style', 'is-comments-minimal') . ' ';
		$html_class .= get_theme_mod('efor_setting_comment_image_shape', 'is-comments-image-rounded') . ' ';
		$html_class .= get_theme_mod('efor_setting_comment_form_style', 'is-comment-form-boxed is-comment-form-border-arrow') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_sidebar_position', 'is-sidebar-right') . ' ';
		$html_class .= get_theme_mod('efor_setting_sidebar_sticky', 'is-sidebar-sticky') . ' ';
		$html_class .= get_theme_mod('efor_setting_sidebar_widget_text_align', 'is-sidebar-align-left') . ' ';
		$html_class .= get_theme_mod('efor_setting_sidebar_widget_title_align', 'is-widget-title-align-left') . ' ';
		$html_class .= get_theme_mod('efor_setting_sidebar_widget_title_style', 'is-widget-line-cut-center') . ' ';
		$html_class .= get_theme_mod('efor_setting_sidebar_trending_posts_style', 'is-trending-posts-default') . ' ';
		
		$html_class .= get_theme_mod('efor_setting_footer_subscribe_style', 'is-footer-subscribe-light') . ' ';
		$html_class .= get_theme_mod('efor_setting_footer_widget_text_align', 'is-footer-widgets-align-left') . ' ';
		$html_class .= get_theme_mod('efor_setting_footer_layout', 'is-footer-full-width');
		
		echo 'class="' . esc_attr($html_class) . '"';
	}
	
	
	function efor_html_data_attributes()
	{
		$html_data_attributes = "";
		
		$font_title_ratio_slider   = get_theme_mod('efor_setting_font_title_ratio', '0.5');
		$font_title_ratio_link_box = get_theme_mod('efor_setting_font_title_ratio_link_box', '0.5');
		
		$html_data_attributes .= 'data-title-ratio="' . esc_attr($font_title_ratio_slider) . '"';
		$html_data_attributes .= ' ';
		$html_data_attributes .= 'data-link-box-title-ratio="' . esc_attr($font_title_ratio_link_box) . '"';
		
		return $html_data_attributes;
	}


/* ============================================================================================================================================= */


	function efor_meta_category()
	{
		?>
			<span class="cat-links">
				<span class="prefix">
					<?php
						esc_html_e('in', 'efor');
					?>
				</span>
				<?php
					the_category(' ');
				?>
			</span>
		<?php
	}
	
	function efor_meta_date()
	{
		?>
			<span class="posted-on">
				<span class="prefix">
					<?php
						esc_html_e('on', 'efor');
					?>
				</span>
				<a href="<?php the_permalink(); ?>" rel="bookmark">
					<time class="entry-date published" datetime="<?php echo get_the_date('c'); ?>">
						<?php
							echo get_the_date();
						?>
					</time>
					<time class="updated" datetime="<?php echo get_the_modified_date('c'); ?>">
						<?php
							echo get_the_modified_date();
						?>
					</time>
				</a>
			</span>
		<?php
	}
	
	function efor_meta_comment_hide_0()
	{
		?>
			<span class="comment-link">
				<span class="prefix">
					<?php
						esc_html_e('with', 'efor');
					?>
				</span>
				<?php
					comments_popup_link(
						esc_html__('0 Comments', 'efor'),
						esc_html__('1 Comment', 'efor'),
						esc_html__('% Comments', 'efor'),
						"",
						esc_html__('Comments Off', 'efor')
					);
				?>
			</span> <!-- .comment-link -->
		<?php
	}
	
	function efor_meta_comment()
	{
		$meta_blog_comment_hide_0 = get_theme_mod('efor_setting_meta_blog_comment_hide_0', true);
		$meta_post_comment_hide_0 = get_theme_mod('efor_setting_meta_post_comment_hide_0', true);
		
		if (is_single())
		{
			if (get_comments_number() || (! $meta_post_comment_hide_0))
			{
				efor_meta_comment_hide_0();
			}
		}
		else
		{
			if (get_comments_number() || (! $meta_blog_comment_hide_0))
			{
				efor_meta_comment_hide_0();
			}
		}
	}
	
	function efor_meta_author()
	{
		?>
			<span class="vcard author">
				<span class="prefix">
					<?php
						esc_html_e('by', 'efor');
					?>
				</span>
				<a class="url fn n" href="<?php echo get_author_posts_url(get_the_author_meta('ID')); ?>">
					<span class="fn">
						<?php
							the_author();
						?>
					</span>
				</a>
			</span>
		<?php
	}
	
	function efor_meta_like()
	{
		?>
			<span class="entry-like">
				<?php
					if (function_exists('dot_irecommendthis'))
					{
						dot_irecommendthis();
					}
				?>
			</span>
		<?php
	}
	
	function efor_meta_share()
	{
		efor_share_links_meta();
	}
	
	function efor_meta_edit()
	{
		edit_post_link(esc_html__('Edit', 'efor'),
					   '<span class="edit-link">',
					   '</span>');
	}
	
	
	function efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control)
	{
		$has_meta = false;
		$meta_position_category = $meta_position[0];
		$meta_position_date     = $meta_position[1];
		$meta_position_comment  = $meta_position[2];
		$meta_position_author   = $meta_position[3];
		$meta_position_share    = $meta_position[4];
		$meta_position_like     = $meta_position[5];
		$meta_position_edit     = $meta_position[6];
		
		if ($meta_position_category == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_category();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_date == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_date();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_comment == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_comment();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_author == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_author();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_share == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_share();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_like == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_like();
			}
			
			$has_meta = true;
		}
		
		if ($meta_position_edit == $meta_wrap_position)
		{
			if (! $meta_control)
			{
				efor_meta_edit();
			}
			
			$has_meta = true;
		}
		
		return $has_meta;
	}
	
	
	function efor_meta($meta_wrap_position)
	{
		$meta_position = array();
		
		if (is_singular('post'))
		{
			$meta_position = array(get_theme_mod('efor_setting_meta_post_cat', 'below_title'),
								   get_theme_mod('efor_setting_meta_post_date', 'below_title'),
								   get_theme_mod('efor_setting_meta_post_comment', 'below_title'),
								   get_theme_mod('efor_setting_meta_post_author', 'hidden'),
								   get_theme_mod('efor_setting_meta_post_share', 'below_title'),
								   get_theme_mod('efor_setting_meta_post_like', 'below_title'),
								   get_theme_mod('efor_setting_meta_post_edit', 'hidden')
								   );
		}
		else
		{
			$meta_position = array(get_theme_mod('efor_setting_meta_blog_cat', 'below_title'),
								   get_theme_mod('efor_setting_meta_blog_date', 'below_title'),
								   get_theme_mod('efor_setting_meta_blog_comment', 'hidden'),
								   get_theme_mod('efor_setting_meta_blog_author', 'hidden'),
								   get_theme_mod('efor_setting_meta_blog_share', 'below_title'),
								   get_theme_mod('efor_setting_meta_blog_like', 'below_title'),
								   get_theme_mod('efor_setting_meta_blog_edit', 'hidden')
								   );
		}
		
		if ($meta_wrap_position == 'above_title')
		{
			if (efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<div class="entry-meta above-title">
						<?php
							efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</div> <!-- .entry-meta .above-title -->
				<?php
			}
		}
		elseif ($meta_wrap_position == 'below_title')
		{
			if (efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<div class="entry-meta below-title">
						<?php
							efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</div> <!-- .entry-meta .below-title -->
				<?php
			}
		}
		elseif ($meta_wrap_position == 'below_content')
		{
			if (efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = true))
			{
				?>
					<footer class="entry-meta below-content">
						<?php
							efor_meta_wrap_position($meta_wrap_position, $meta_position, $meta_control = false);
						?>
					</footer> <!-- .entry-meta .below-content -->
				<?php
			}
		}
	}


/* ============================================================================================================================================= */


	function efor_gallery_type__slider($atts)
	{
		extract(shortcode_atts(array('ids'     => "",
									 'orderby' => "",
									 'link'    => "",
									 'size'    => 'thumbnail'), $atts));
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$output .= '<div class="owl-carousel" data-items="1" data-loop="true" data-center="false" data-mouse-drag="true" data-nav="true" data-dots="true" data-autoplay="false" data-autoplay-speed="600" data-autoplay-timeout="2000">';
			
				if (is_page_template('page_template-full.php') || is_page_template('page_template-medium.php') || is_singular('portfolio'))
				{
					$size = 'efor_image_size_7';
				}
				else
				{
					$size = 'efor_image_size_1';
				}
				
				foreach ($items_in_array as $item)
				{
					$image 		   = wp_get_attachment_image_src($item, $size);
					$image_alt 	   = get_post_meta($item, '_wp_attachment_image_alt', true);
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = '<p class="owl-title">' . $image_caption . '</p>';
					}
					
					$output .= '<div>';
					$output .= '<img alt="' . esc_attr($image_alt) . '" src="' . esc_url($image[0]) . '">';
					$output .= $image_caption;
					$output .= '</div>';
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}
	
	
	function efor_gallery_type__grid($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'link'    => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = "";
			
			if (is_array($items_with_commas))
			{
				$items_in_array = $items_with_commas;
			}
			else
			{
				$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			}
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$output .= '<div class="gallery ' . (($link == "") ? 'link-to-attachment-page' : 'link-to-' . $link) . '">';
			
				foreach ($items_in_array as $item)
				{
					$image_big = "";
					$image_big_width_cropped = wp_get_attachment_image_src($item, 'efor_image_size_7'); // magnific-popup-width
					
					if ($image_big_width_cropped[1] > $image_big_width_cropped[2])
					{
						$image_big = $image_big_width_cropped[0];
					}
					else
					{
						$image_big_height_cropped = wp_get_attachment_image_src($item, 'efor_image_size_8'); // magnific-popup-height
						$image_big = $image_big_height_cropped[0];
					}
					
					$image_small = "";
					
					if ($size == 'full')
					{
						$image_small = wp_get_attachment_image_src($item, 'efor_image_size_1'); // gallery-type-grid
					}
					else
					{
						$image_small = wp_get_attachment_image_src($item, 'efor_image_size_6'); // gallery-type-grid
					}
					
					$image_alt 	   = get_post_meta($item, '_wp_attachment_image_alt', true);
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = '<figcaption class="wp-caption-text gallery-caption">' . $image_caption . '</figcaption>';
					}
					
					if ($link == 'file')
					{
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<a href="' . esc_url($image_big) . '">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</a>';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
					elseif ($link == 'none')
					{
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
					else
					{
						$attachment_page = get_attachment_link($item);
						
						$output .= '<figure class="gallery-item">';
						$output .= '<div class="gallery-icon landscape">';
						$output .= '<a href="' . esc_url($attachment_page) . '">';
						$output .= '<img class="attachment-thumbnail" alt="' . esc_attr($image_alt) . '" src="' . esc_url($image_small[0]) . '">';
						$output .= '</a>';
						$output .= '</div>';
						$output .= $image_caption;
						$output .= '</figure>';
					}
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}
	
	
	function efor_portfolio_page__lightbox_gallery($atts)
	{
		extract(shortcode_atts(array('ids'     => "",
									 'orderby' => "",
									 'link'    => "",
									 'size'    => 'thumbnail'), $atts));
		
		$output = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
				$first_item = true;
				global $efor_portfolio_item_has_feat_img;
				$feat_img = $efor_portfolio_item_has_feat_img;
				global $efor_portfolio_page_grid_type__lightbox_gallery;
				
				foreach ($items_in_array as $item)
				{
					$image_big = "";
					$image_big_width_cropped = wp_get_attachment_image_src($item, 'efor_image_size_7'); // magnific-popup-width
					
					if ($image_big_width_cropped[1] > $image_big_width_cropped[2])
					{
						$image_big = $image_big_width_cropped[0];
					}
					else
					{
						$image_big_height_cropped = wp_get_attachment_image_src($item, 'efor_image_size_8'); // magnific-popup-height
						$image_big = $image_big_height_cropped[0];
					}
					
					$image_caption = get_post_field('post_excerpt', $item);
					
					if ($image_caption != "")
					{
						$image_caption = 'title="' . esc_attr($image_caption) . '"';
					}
					
					if ($first_item)
					{
						if ($feat_img)
						{
							$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '">' . efor_portfolio_item_feat_img__lightbox_gallery($efor_portfolio_page_grid_type__lightbox_gallery) . '</a>';
						}
						else
						{
							$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '">' . get_the_title() . '</a>';
						}
						
						$first_item = false;
					}
					else
					{
						$output .= '<a class="lightbox" ' . $image_caption . ' href="' . esc_url($image_big) . '"></a>';
					}
				}
		}
		
		return $output;
	}
	
	
	function efor_post_gallery($output = "", $atts, $content = false, $tag = false)
	{
		$new_output = $output;
		
		if ((is_page_template('page_template-portfolio.php') || is_tax('portfolio-category')) && has_post_format('gallery'))
		{
			$new_output = efor_portfolio_page__lightbox_gallery($atts);
		}
		else
		{
			$gallery_type = get_option('efor_gallery_type' . '__' . get_the_ID(), 'grid');
			
			if ($gallery_type == 'slider')
			{
				$new_output = efor_gallery_type__slider($atts);
			}
			else
			{
				$new_output = efor_gallery_type__grid($atts);
			}
		}
		
		return $new_output;
	}
	
	add_filter('post_gallery', 'efor_post_gallery', 10, 4);


/* ============================================================================================================================================= */


	if (! function_exists('efor_archive_layout'))
	{
		function efor_archive_layout()
		{
			$layout = 'Regular';
			
			if (is_home() || is_tax('post_format'))
			{
				$layout = get_theme_mod('efor_setting_layout_blog', 'Regular');
			}
			elseif (is_tax())
			{
				$layout = 'Other'; // Custom taxonomy archives.
			}
			elseif (is_category())
			{
				$layout = get_theme_mod('efor_setting_layout_category', 'Grid');
			}
			elseif (is_tag())
			{
				$layout = get_theme_mod('efor_setting_layout_tag', 'Grid');
			}
			elseif (is_author())
			{
				$layout = get_theme_mod('efor_setting_layout_author', 'Grid');
			}
			elseif (is_date())
			{
				$layout = get_theme_mod('efor_setting_layout_date', 'Grid');
			}
			elseif (is_search())
			{
				$layout = get_theme_mod('efor_setting_layout_search', 'Grid');
			}
			elseif (is_archive())
			{
				$layout = 'Other'; // Other archives.
			}
			
			return $layout;
		}
	}


/* ============================================================================================================================================= */


	function efor_1st_full_yes_no()
	{
		$first_full = 'No';
		
		if (isset($_GET['first_full']))
		{
			if ($_GET['first_full'] == 'yes')
			{
				$first_full = 'Yes';
			}
			else
			{
				$first_full = 'No';
			}
		}
		else
		{
			$layout = efor_archive_layout();
			
			if (($layout == '1st Full + Grid') || ($layout == '1st Full + List'))
			{
				$first_full = 'Yes';
			}
		}
		
		return $first_full;
	}


/* ============================================================================================================================================= */


	function efor_category_link_style()
	{
		return get_theme_mod('efor_setting_meta_cat_link_style', 'is-cat-link-line-before');
	}
	
	
	function efor_blog_grid_post_width()
	{
		$grid_post_width = get_theme_mod('efor_setting_grid_post_width', '340');
		
		echo esc_attr($grid_post_width);
	}
	
	
	function efor_blog_grid_type()
	{
		$grid_type = 'masonry';
		
		if (isset($_GET['grid_type']))
		{
			if ($_GET['grid_type'] == 'fitRows')
			{
				$grid_type = 'fitRows';
			}
			else
			{
				$grid_type = 'masonry';
			}
		}
		else
		{
			$grid_type = get_theme_mod('efor_setting_grid_type', 'masonry');
		}
		
		return esc_attr($grid_type);
	}


/* ============================================================================================================================================= */


	if (! function_exists('efor_portfolio_page__post_class'))
	{
		function efor_portfolio_page__post_class()
		{
			$taxonomy         = 'portfolio-category';
			$categories_slugs = "";
			$categories 	  = get_the_terms(get_the_ID(), $taxonomy);
			
			if ($categories && (! is_wp_error($categories)))
			{
				foreach ($categories as $category)
				{
					// Get post's category slug and its parent category slug.
					
					$categories_slugs .= get_term_parents_list(
						$category->term_id,
						$taxonomy,
						array(
							'format'    => 'slug',
							'separator' => ' ',
							'link'      => false,
							'inclusive' => true,
						)
					);
				}
			}
			
			$post_class = esc_attr($categories_slugs);
			
			return $post_class;
		}
	}


/* ============================================================================================================================================= */


	function efor_iframe_from_xml($browser_address_url)
	{
		$browser_address_url__type_youtube    = strpos($browser_address_url, 'youtube.com');
		$browser_address_url__type_vimeo      = strpos($browser_address_url, 'vimeo.com');
		$browser_address_url__type_soundcloud = strpos($browser_address_url, 'soundcloud.com');
		
		if ($browser_address_url__type_youtube !== false)
		{
			$xml_url 	   = 'http://www.youtube.com/oembed?url=' . $browser_address_url . '&format=xml';
			$xml_content   = simplexml_load_file($xml_url);
			$xml_attribute = $xml_content->html; // Get iframe.
			return $xml_attribute;
		}
		elseif ($browser_address_url__type_vimeo !== false)
		{
			$xml_url 	   = 'http://vimeo.com/api/oembed.xml?url=' . $browser_address_url;
			$xml_content   = simplexml_load_file($xml_url);
			$xml_attribute = $xml_content->html; // Get iframe.
			return $xml_attribute;
		}
		elseif ($browser_address_url__type_soundcloud !== false)
		{
			$xml_url 	   = 'http://soundcloud.com/oembed?url=' . $browser_address_url;
			$xml_content   = simplexml_load_file($xml_url);
			$xml_attribute = $xml_content->html; // Get iframe.
			return $xml_attribute;
		}
	}


/* ============================================================================================================================================= */


	function efor_wp_head__theme_directory_url()
	{
		// Used for local_font_url in customizer.
		
		if (is_customize_preview())
		{
			$theme_directory_url = get_template_directory_uri(); // http://www.example.com/wp-content/themes/efor
			
			// Remove URL prefix http: OR https:
			
			$theme_directory_url__http  = strpos($theme_directory_url, 'http:'); // Check for http:
			$theme_directory_url__https = strpos($theme_directory_url, 'https:'); // Check for https:
			
			if ($theme_directory_url__http !== false)
			{
				$theme_directory_url = substr($theme_directory_url, 5); // Remove http:
			}
			elseif ($theme_directory_url__https !== false)
			{
				$theme_directory_url = substr($theme_directory_url, 6); // Remove https:
			}
			
			// end Remove URL prefix http: OR https:
			
			?>

<meta id="efor_theme_directory_url" name="efor_theme_directory_url" content="<?php echo esc_url($theme_directory_url); ?>">

			<?php
		}
	}
	
	add_action('wp_head', 'efor_wp_head__theme_directory_url');


/* ============================================================================================================================================= */


	/*
		This function filters the post content when viewing a post with the "chat" post format.  It formats the 
		content with structured HTML markup to make it easy for theme developers to style chat posts. The 
		advantage of this solution is that it allows for more than two speakers (like most solutions). You can 
		have 100s of speakers in your chat post, each with their own, unique classes for styling.
		
		@author David Chandra
		@link http://www.turtlepod.org
		@author Justin Tadlock
		@link http://justintadlock.com
		@copyright Copyright (c) 2012
		@license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
		@link http://justintadlock.com/archives/2012/08/21/post-formats-chat
		
		@global array $_post_format_chat_ids An array of IDs for the chat rows based on the author.
		@param string $content The content of the post.
		@return string $chat_output The formatted content of the post.
	*/
	
	function efor_theme_post_format_chat_content( $content )
	{
		global $_post_format_chat_ids;
		
		/* If this is not a 'chat' post, return the content. */
		if ( !has_post_format( 'chat' ) )
		{
			return $content;
		}
		
		/* Set the global variable of speaker IDs to a new, empty array for this chat. */
		$_post_format_chat_ids = array();
		
		/* Allow the separator (separator for speaker/text) to be filtered. */
		$separator = apply_filters( 'my_post_format_chat_separator', ':' );
		
		/* Open the chat transcript div and give it a unique ID based on the post ID. */
		$chat_output = "\n\t\t\t" . '<div id="chat-transcript-' . esc_attr( get_the_ID() ) . '" class="chat-transcript">';
		
		/* Split the content to get individual chat rows. */
		$chat_rows = preg_split( "/(\r?\n)+|(<br\s*\/?>\s*)+/", $content );
		
		/* Loop through each row and format the output. */
		foreach ( $chat_rows as $chat_row )
		{
			/* If a speaker is found, create a new chat row with speaker and text. */
			if ( strpos( $chat_row, $separator ) )
			{
				/* Split the chat row into author/text. */
				$chat_row_split = explode( $separator, trim( $chat_row ), 2 );
				
				/* Get the chat author and strip tags. */
				$chat_author = strip_tags( trim( $chat_row_split[0] ) );
				
				/* Get the chat text. */
				$chat_text = trim( $chat_row_split[1] );
				
				/* Get the chat row ID (based on chat author) to give a specific class to each row for styling. */
				$speaker_id = efor_theme_post_format_chat_row_id( $chat_author );
				
				/* Open the chat row. */
				$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
				
				/* Add the chat row author. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-author ' . sanitize_html_class( strtolower( "chat-author-{$chat_author}" ) ) . ' vcard"><cite class="fn">' . apply_filters( 'my_post_format_chat_author', $chat_author, $speaker_id ) . '</cite>' . $separator . '</div>';
				
				/* Add the chat row text. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text"><p>' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_text, $chat_author, $speaker_id ) ) . '</p></div>';
				
				/* Close the chat row. */
				$chat_output .= "\n\t\t\t\t" . '</div><!-- .chat-row -->';
			}
			/*
				If no author is found, assume this is a separate paragraph of text that belongs to the
				previous speaker and label it as such, but let's still create a new row.
			*/
			else
			{
				/* Make sure we have text. */
				if ( !empty( $chat_row ) )
				{
					/* Open the chat row. */
					$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
					
					/* Don't add a chat row author.  The label for the previous row should suffice. */
					
					/* Add the chat row text. */
					$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text"><p>' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_row, $chat_author, $speaker_id ) ) . '</p></div>';
					
					/* Close the chat row. */
					$chat_output .= "\n\t\t\t</div><!-- .chat-row -->";
				}
			}
		}
		
		/* Close the chat transcript div. */
		$chat_output .= "\n\t\t\t</div><!-- .chat-transcript -->\n";
		
		/* Return the chat content and apply filters for developers. */
		return apply_filters( 'my_post_format_chat_content', $chat_output );
	}
	
	/*
		This function returns an ID based on the provided chat author name. It keeps these IDs in a global 
		array and makes sure we have a unique set of IDs.  The purpose of this function is to provide an "ID"
		that will be used in an HTML class for individual chat rows so they can be styled. So, speaker "John" 
		will always have the same class each time he speaks. And, speaker "Mary" will have a different class 
		from "John" but will have the same class each time she speaks.
		
		@author David Chandra
		@link http://www.turtlepod.org
		@author Justin Tadlock
		@link http://justintadlock.com
		@copyright Copyright (c) 2012
		@license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
		@link http://justintadlock.com/archives/2012/08/21/post-formats-chat
		
		@global array $_post_format_chat_ids An array of IDs for the chat rows based on the author.
		@param string $chat_author Author of the current chat row.
		@return int The ID for the chat row based on the author.
	*/
	
	function efor_theme_post_format_chat_row_id( $chat_author )
	{
		global $_post_format_chat_ids;
		
		/* Let's sanitize the chat author to avoid craziness and differences like "John" and "john". */
		$chat_author = strtolower( strip_tags( $chat_author ) );
		
		/* Add the chat author to the array. */
		$_post_format_chat_ids[] = $chat_author;
		
		/* Make sure the array only holds unique values. */
		$_post_format_chat_ids = array_unique( $_post_format_chat_ids );
		
		/* Return the array key for the chat author and add "1" to avoid an ID of "0". */
		return absint( array_search( $chat_author, $_post_format_chat_ids ) ) + 1;
	}
	
	/* Filter the content of chat posts. */
	add_filter( 'the_content', 'efor_theme_post_format_chat_content' );


/* ============================================================================================================================================= */


	function efor_blog_page_link_html($url)
	{
		?>
			<div class="section-launch">
				<a class="button" href="<?php echo esc_url($url); ?>">
					<?php
						esc_html_e('See All Posts', 'efor');
					?>
				</a> <!-- .button -->
			</div> <!-- .section-launch -->
		<?php
	}
	
	function efor_blog_page_link()
	{
		$front_page_displays = get_option('show_on_front');
		
		if ($front_page_displays == 'posts')
		{
			$home_url = home_url('/');
			efor_blog_page_link_html($home_url);
		}
		else
		{
			$blog_page_id = get_option('page_for_posts');
			
			if ($blog_page_id)
			{
				$blog_page_url = get_page_link($blog_page_id);
				efor_blog_page_link_html($blog_page_url);
			}
		}
	}


/* ============================================================================================================================================= */


	function efor_core_featured_media__url()
	{
		if (function_exists('pixelwars_core_featured_media__url'))
		{
			return pixelwars_core_featured_media__url();
		}
	}
	
	
	function efor_core_featured_media__new_tab()
	{
		if (function_exists('pixelwars_core_featured_media__new_tab'))
		{
			return pixelwars_core_featured_media__new_tab();
		}
	}


/* ============================================================================================================================================= */


	function efor_share_links_meta()
	{
		if (function_exists('pixelwars_core_share_links_meta'))
		{
			pixelwars_core_share_links_meta();
		}
	}
	
	
	function efor_share_links()
	{
		$share_links = get_theme_mod('efor_setting_share_links', 'Yes');
		
		if ($share_links != 'No')
		{
			if (function_exists('pixelwars_core_share_links'))
			{
				pixelwars_core_share_links();
			}
		}
	}


/* ============================================================================================================================================= */


	if (is_admin())
	{
		include_once(get_template_directory() . '/admin/theme-options.php');
	}
	
	
	include_once(get_template_directory() . '/admin/pre-get-posts.php');
	include_once(get_template_directory() . '/admin/posts-columns.php');
	
	include_once(get_template_directory() . '/admin/functions-header.php');
	include_once(get_template_directory() . '/admin/functions-layout-regular.php');
	include_once(get_template_directory() . '/admin/functions-layout-grid.php');
	include_once(get_template_directory() . '/admin/functions-portfolio.php');
	include_once(get_template_directory() . '/admin/functions-woocommerce.php');
	
	include_once(get_template_directory() . '/admin/meta-box-title-visibility.php');
	include_once(get_template_directory() . '/admin/meta-box-sidebar.php');
	include_once(get_template_directory() . '/admin/meta-box-post-style.php');
	include_once(get_template_directory() . '/admin/meta-box-gallery-type.php');
	include_once(get_template_directory() . '/admin/meta-box-featured-area.php');
	
	include_once(get_template_directory() . '/admin/widget_area-register.php');
	include_once(get_template_directory() . '/admin/widget_area-featured-area.php');
	include_once(get_template_directory() . '/admin/widget_area-sidebar.php');
	
	include_once(get_template_directory() . '/admin/content-none.php');
	include_once(get_template_directory() . '/admin/archive-title.php');
	include_once(get_template_directory() . '/admin/automatic-excerpt.php');
	include_once(get_template_directory() . '/admin/related-posts.php');
	include_once(get_template_directory() . '/admin/customizer.php');
	include_once(get_template_directory() . '/admin/install-plugins.php');
	include_once(get_template_directory() . '/admin/demo-import.php');

?>